# A description of what this class does
#
# @summary A short summary of the purpose of this class
#
# @example
#   include workstation::asdf::manage
class workstation::asdf::manage (
  Enum['bash', 'zsh', 'fish'] $shell = $workstation::shell,
  String[1] $user = $workstation::user,
  String[1] $home = $workstation::home,
  String[1] $repo = 'https://github.com/asdf-vm/asdf.git',
) {

  vcsrepo { "${home}/.asdf":
    ensure   => latest,
    provider => git,
    source   => $repo,
    owner    => $user,
  }

  if $shell in ['bash', 'zsh'] {
    if $shell == 'zsh' {
      $config_file = "${home}/.zshrc"
    } else {
      $config_file = $facts['os']['family'] ? {
        'Darwin' => "${home}/.bash_profile",
        'Linux'  => "${home}/.bashrc",
      }
    }
    file_line { 'asdf_sh':
      path => $config_file,
      line => '. $HOME/.asdf/asdf.sh',
    }
    file_line { 'asdf_completions':
      path => $config_file,
      line => '. $HOME/.asdf/completions/asdf.bash',
    }
  } else {
    file_line { 'source_asdf_fish':
      path => "${home}/.config/fish/config.fish",
      line => 'source ~/.asdf/asdf.fish',
    }
    -> file { "${home}/.config/fish/completions":
      ensure => directory,
      owner  => $user,
    }
    -> exec { '/bin/cp .asdf/completions/asdf.fish .config/fish/completions':
      user    => $user,
      cwd     => $home,
      creates => "${home}/.config/fish/completions/asdf.fish",
    }
  }

}
