# A description of what this class does
#
# @summary A short summary of the purpose of this class
#
# @example
#   include workstation::mac::homebrew::packages
class workstation::mac::homebrew::packages (
  Optional[Hash[String[1], Array[String[1]]]] $packages = $workstation::mac::homebrew::packages,
) {

  if $packages {
    if has_key($packages, 'taps') {
      $taps = $packages['taps']
    } else {
      $taps = undef
    }

    if has_key($packages, 'formulae') {
      $formulae = $packages['formulae']
    } else {
      $formulae = undef
    }

    if has_key($packages, 'casks') {
      $casks = $packages['casks']
    } else {
      $caks = undef
    }

    if $taps {
      $taps.each |String $tap| {
        package { $tap:
          ensure   => present,
          provider => 'tap',
        }
      }
    }

    if $formulae {
      $formulae.each |String $formula| {
        package { "formula_${formula}":
          ensure   => present,
          name     => $formula,
          provider => 'brew',
        }
      }
    }

    if $casks {
      $casks.each |String $cask| {
        package { "cask_${cask}":
          ensure   => present,
          name     => $cask,
          provider => 'brewcask',
          require  => Package[$taps],
        }
      }
    }
  } else {
    notice('No homebrew formulae, taps, or casks provided.')
  }

}
